==> mautrix-meta-0.4.2.tar.gz: meta-0.4.2/pkg/messagix/taskManager.go <==
package messagix

import (
	"encoding/json"
	"strconv"

	"go.mau.fi/mautrix-meta/pkg/messagix/methods"
	"go.mau.fi/mautrix-meta/pkg/messagix/socket"
)

type TaskManager struct {
	client    *Client
	currTasks []socket.TaskData
	traceId   string
}

func (c *Client) NewTaskManager() *TaskManager {
	return &TaskManager{
		client:    c,
		currTasks: make([]socket.TaskData, 0),
		traceId:   "",
	}
}

func (tm *TaskManager) FinalizePayload() ([]byte, error) {
	p := &socket.TaskPayload{
		EpochId:     methods.GenerateEpochId(),
		Tasks:       tm.currTasks,
		DataTraceId: tm.traceId,
		VersionId:   strconv.FormatInt(tm.client.configs.VersionId, 10),
	}
	tm.currTasks = make([]socket.TaskData, 0)
	return json.Marshal(p)
}

//lint:ignore U1000 -
func (tm *TaskManager) setTraceId(traceId string) {
	tm.traceId = traceId
}

func (tm *TaskManager) AddNewTask(task socket.Task) {
	payload, queueName, marshalQueueName := task.Create()
	label := task.GetLabel()

	payloadMarshalled, err := json.Marshal(payload)
	if err != nil {
		tm.client.Logger.Err(err).Any("label", label).Msg("failed to marshal task payload")
		return
	}

	if marshalQueueName {
		queueName, err = json.Marshal(queueName)
		if err != nil {
			tm.client.Logger.Err(err).Any("label", label).Msg("failed to marshal queueName information for task")
			return
		}
		queueName = string(queueName.([]byte))
	}

	taskData := socket.TaskData{
		FailureCount: nil,
		Label:        label,
		Payload:      string(payloadMarshalled),
		QueueName:    queueName,
		TaskId:       tm.GetTaskId(),
	}
	tm.client.Logger.Trace().Any("label", label).Any("payload", payload).Any("queueName", queueName).Any("taskId", taskData.TaskId).Msg("Creating task")

	tm.currTasks = append(tm.currTasks, taskData)
}

func (tm *TaskManager) GetTaskId() int64 {
	return int64(tm.client.GetTaskId())
}

==> mautrix-meta-0.4.5.tar.gz: meta-0.4.5/pkg/messagix/taskManager.go <==
package messagix

import (
	"encoding/json"
	"strconv"

	"go.mau.fi/mautrix-meta/pkg/messagix/methods"
	"go.mau.fi/mautrix-meta/pkg/messagix/socket"
)

type TaskManager struct {
	client    *Client
	currTasks []socket.TaskData
	traceId   string
}

func (c *Client) newTaskManager() *TaskManager {
	return &TaskManager{
		client:    c,
		currTasks: make([]socket.TaskData, 0),
		traceId:   "",
	}
}

func (tm *TaskManager) FinalizePayload() ([]byte, error) {
	p := &socket.TaskPayload{
		EpochId:     methods.GenerateEpochId(),
		Tasks:       tm.currTasks,
		DataTraceId: tm.traceId,
		VersionId:   strconv.FormatInt(tm.client.configs.VersionId, 10),
	}
	tm.currTasks = make([]socket.TaskData, 0)
	return json.Marshal(p)
}

//lint:ignore U1000 -
func (tm *TaskManager) setTraceId(traceId string) {
	tm.traceId = traceId
}

func (tm *TaskManager) AddNewTask(task socket.Task) {
	payload, queueName, marshalQueueName := task.Create()
	label := task.GetLabel()

	payloadMarshalled, err := json.Marshal(payload)
	if err != nil {
		tm.client.Logger.Err(err).Any("label", label).Msg("failed to marshal task payload")
		return
	}

	if marshalQueueName {
		queueName, err = json.Marshal(queueName)
		if err != nil {
			tm.client.Logger.Err(err).Any("label", label).Msg("failed to marshal queueName information for task")
			return
		}
		queueName = string(queueName.([]byte))
	}

	taskData := socket.TaskData{
		FailureCount: nil,
		Label:        label,
		Payload:      string(payloadMarshalled),
		QueueName:    queueName,
		TaskId:       tm.GetTaskID(),
	}
	tm.client.Logger.Trace().Any("label", label).Any("payload", payload).Any("queueName", queueName).Any("taskId", taskData.TaskId).Msg("Creating task")

	tm.currTasks = append(tm.currTasks, taskData)
}

func (tm *TaskManager) GetTaskID() int64 {
	return int64(tm.client.getTaskID())
}
